Coverage report

# Coverage report: 32%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 348 | 237 | 0 | 32%
C:\checkouts\github\OpenQTSim\openqtsim\__init__.py | 11 | 0 | 0 | 100%
C:\checkouts\github\OpenQTSim\openqtsim\arrival_process.py | 9 | 4 | 0 | 56%
C:\checkouts\github\OpenQTSim\openqtsim\customer.py | 33 | 30 | 0 | 9%
C:\checkouts\github\OpenQTSim\openqtsim\mm1.py | 63 | 55 | 0 | 13%
C:\checkouts\github\OpenQTSim\openqtsim\mt_engine.py | 16 | 10 | 0 | 38%
C:\checkouts\github\OpenQTSim\openqtsim\queue.py | 60 | 23 | 0 | 62%
C:\checkouts\github\OpenQTSim\openqtsim\service_process.py | 9 | 4 | 0 | 56%
C:\checkouts\github\OpenQTSim\openqtsim\simulation.py | 111 | 95 | 0 | 14%
C:\checkouts\github\OpenQTSim\openqtsim\tables.py | 20 | 16 | 0 | 20%
__init__.py | 0 | 0 | 0 | 100%
conftest.py | 0 | 0 | 0 | 100%
test_basics.py | 16 | 0 | 0 | 100%

No items found using the specified filter.